@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna.php,v 1.11 2004/12/23 06:05:42 fujimoto Exp $
+ *	@version	$Id: Ethna.php,v 1.15 2005/01/12 17:15:29 fujimoto Exp $
  */
 
 /** Ethna¸饤֥: PEAR, PEAR_Error */
@@ -20,7 +20,7 @@ include_once('Smarty/Smarty.class.php');
 
 
 /** С */
-define('ETHNA_VERSION', '0.1.2');
+define('ETHNA_VERSION', '0.1.3');
 
 /** Ethna١ǥ쥯ȥ */
 define('ETHNA_BASE', dirname(__FILE__));
@@ -35,6 +35,7 @@ include_once(ETHNA_BASE . '/class/Ethna_AppSearchObject.php');
 include_once(ETHNA_BASE . '/class/Ethna_Backend.php');
 include_once(ETHNA_BASE . '/class/Ethna_Config.php');
 include_once(ETHNA_BASE . '/class/Ethna_Controller.php');
+include_once(ETHNA_BASE . '/class/Ethna_ClassFactory.php');
 include_once(ETHNA_BASE . '/class/Ethna_DB.php');
 include_once(ETHNA_BASE . '/class/Ethna_Filter.php');
 include_once(ETHNA_BASE . '/class/Ethna_I18N.php');
@@ -130,7 +131,7 @@ define('FORM_TYPE_CHECKBOX', 6);
 /** ե෿: button */
 define('FORM_TYPE_SUBMIT', 7);
 
-/** ե෿: button */
+/** ե෿: file */
 define('FORM_TYPE_FILE', 8);
 
 
