@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_ActionForm.php,v 1.9 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_ActionForm.php,v 1.13 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 /** 귿ե륿: Ⱦ */
@@ -30,9 +30,7 @@ class Ethna_ActionForm
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	array	ե
-	 */
+	/**	@var	array	ե */
 	var $form = array();
 
 	/**
@@ -40,39 +38,25 @@ class Ethna_ActionForm
 	 */
 	var $form_vars = array();
 
-	/**
-	 *	@var	array	ץꥱ
-	 */
+	/**	@var	array	ץꥱ */
 	var $app_vars = array();
 
-	/**
-	 *	@var	array	ץꥱ(ưפʤ)
-	 */
+	/**	@var	array	ץꥱ(ưפʤ) */
 	var $app_ne_vars = array();
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥ */
 	var $action_error;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥(ά) */
 	var $ae;
 
-	/**
-	 *	@var	object	Ethna_I18N	i18n֥
-	 */
+	/**	@var	object	Ethna_I18N	i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_Logger	֥
-	 */
+	/**	@var	object	Ethna_Logger	֥ */
 	var $logger;
 
-	/**
-	 *	@var	array	ե
-	 */
+	/**	@var	array	ե */
 	var $def = array('name', 'required', 'max', 'min', 'regexp', 'custom', 'filter', 'form_type', 'type');
 
 	/**#@-*/
@@ -145,11 +129,20 @@ class Ethna_ActionForm
 	 *	ե
 	 *
 	 *	@access	public
+	 *	@param	string	$name	ե̾(ά:nullʤƤ)
 	 *	@return	array	ե
 	 */
-	function getDef()
+	function getDef($name = null)
 	{
-		return $this->form;
+		if (is_null($name)) {
+			return $this->form;
+		}
+
+		if (array_key_exists($name, $this->form) == false) {
+			return null;
+		} else {
+			return $this->form[$name];
+		}
 	}
 
 	/**
@@ -328,7 +321,7 @@ class Ethna_ActionForm
 					$valid_keys[] = $k;
 				}
 				if (count($valid_keys) == 0 && $value['required']) {
-					$this->_handleError($name, $value, E_FORM_REQUIRED);
+					$this->handleError($name, E_FORM_REQUIRED);
 					continue;
 				} else if (count($valid_keys) == 0 && $value['required'] == false) {
 					continue;
@@ -337,7 +330,7 @@ class Ethna_ActionForm
 				if (is_array($this->form_vars[$name]['tmp_name'])) {
 					if (is_array($value['type']) == false) {
 						// ñΥեϤƤ
-						$this->_handleError($name, $value, E_FORM_WRONGTYPE_SCALAR);
+						$this->handleError($name, E_FORM_WRONGTYPE_SCALAR);
 						continue;
 					}
 
@@ -355,10 +348,14 @@ class Ethna_ActionForm
 					foreach (array_keys($this->form_vars[$name]) as $key) {
 						$this->_validate($name, $this->form_vars[$name][$key], $value);
 					}
+					// ᥽åɤμ¹
+					if ($value['custom'] != null) {
+						$this->{$value['custom']}($name);
+					}
 				} else {
 					if (is_array($value['type'])) {
 						// Υե˥顼ͤϤƤ
-						$this->_handleError($name, $value, E_FORM_WRONGTYPE_ARRAY);
+						$this->handleError($name, E_FORM_WRONGTYPE_ARRAY);
 						continue;
 					}
 					if (count($valid_keys) == 0) {
@@ -370,7 +367,7 @@ class Ethna_ActionForm
 				if (is_array($this->form_vars[$name])) {
 					if (is_array($value['type']) == false) {
 						// 顼ΥեϤƤ
-						$this->_handleError($name, $value, E_FORM_WRONGTYPE_SCALAR);
+						$this->handleError($name, E_FORM_WRONGTYPE_SCALAR);
 						continue;
 					}
 
@@ -379,13 +376,22 @@ class Ethna_ActionForm
 						$this->form_vars[$name][$key] = $this->_filter($this->form_vars[$name][$key], $value['filter']);
 						$this->_validate($name, $this->form_vars[$name][$key], $value);
 					}
+					// ᥽åɤμ¹
+					if ($value['custom'] != null) {
+						$this->{$value['custom']}($name);
+					}
 				} else {
-					if ($this->form_vars[$name] == null && is_array($value['type']) && $value['required'] == false) {
-						// 󷿤ǾάĤΤΤͼΤƤʤƤ⥨顼Ȥʤ
-						continue;
-					} else if (is_array($value['type'])) {
-						$this->_handleError($name, $value, E_FORM_WRONGTYPE_ARRAY);
-						continue;
+					if (is_array($value['type'])) {
+						if ($this->form_vars[$name] == null && $value['required'] == false) {
+							// 󷿤ǾάĤΤΤͼΤƤʤƤ⥨顼Ȥʤ
+							continue;
+						} else if ($this->form_vars[$name] == null) {
+							$this->handleError($name, E_FORM_REQUIRED);
+							continue;
+						} else {
+							$this->handleError($name, E_FORM_WRONGTYPE_ARRAY);
+							continue;
+						}
 					}
 					$this->form_vars[$name] = $this->_filter($this->form_vars[$name], $value['filter']);
 					$this->_validate($name, $this->form_vars[$name], $value);
@@ -467,6 +473,9 @@ class Ethna_ActionForm
 			return null;
 		}
 		foreach ($form_vars as $v) {
+			if ($v === "") {
+				continue;
+			}
 			if ($v != "0" && $v != "1") {
 				return $this->ae->add($name, '{form}ϤƤ', E_FORM_INVALIDCHAR);
 			}
@@ -488,6 +497,9 @@ class Ethna_ActionForm
 			return null;
 		}
 		foreach ($form_vars as $v) {
+			if ($v === "") {
+				continue;
+			}
 			if (Ethna_Util::checkMailaddress($v) == false) {
 				return $this->ae->add($name, '{form}ϤƤ', E_FORM_INVALIDCHAR);
 			}
@@ -509,6 +521,9 @@ class Ethna_ActionForm
 			return null;
 		}
 		foreach ($form_vars as $v) {
+			if ($v === "") {
+				continue;
+			}
 			if (preg_match('/^(http:\/\/|https:\/\/|ftp:\/\/)/', $v) == 0) {
 				return $this->ae->add($name, '{form}ϤƤ', E_FORM_INVALIDCHAR);
 			}
@@ -558,15 +573,15 @@ class Ethna_ActionForm
 	/**
 	 *	ե͸ڤΥ顼Ԥ
 	 *
-	 *	@access	protected
+	 *	@access	public
 	 *	@param	string		$name	ե̾
-	 *	@param	array		$value	ե
 	 *	@param	int			$code	顼
 	 */
-	function _handleError($name, $value, $code)
+	function handleError($name, $code)
 	{
+		$def = $this->getDef($name);
 		if ($code == E_FORM_REQUIRED) {
-			switch ($value['form_type']) {
+			switch ($def['form_type']) {
 			case FORM_TYPE_TEXT:
 			case FORM_TYPE_PASSWORD:
 			case FORM_TYPE_TEXTAREA:
@@ -596,34 +611,34 @@ class Ethna_ActionForm
 		} else if ($code == E_FORM_WRONGTYPE_BOOLEAN) {
 			$message = "{form}ˤ1ޤ0ΤϤǤޤ";
 		} else if ($code == E_FORM_MIN_INT) {
-			$this->ae->add($name, "{form}ˤ%dʾο()ϤƲ", $code, $value['min']);
+			$this->ae->add($name, "{form}ˤ%dʾο()ϤƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MIN_FLOAT) {
-			$this->ae->add($name, "{form}ˤ%fʾο()ϤƲ", $code, $value['min']);
+			$this->ae->add($name, "{form}ˤ%fʾο()ϤƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MIN_DATETIME) {
-			$this->ae->add($name, "{form}ˤ%sʹߤդϤƲ", $code, $value['min']);
+			$this->ae->add($name, "{form}ˤ%sʹߤդϤƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MIN_FILE) {
-			$this->ae->add($name, "{form}ˤ%dKBʾΥեꤷƲ", $code, $value['min']);
+			$this->ae->add($name, "{form}ˤ%dKBʾΥեꤷƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MIN_STRING) {
-			$this->ae->add($name, "{form}ˤ%dʸʾϤƲ", $code, $value['min']);
+			$this->ae->add($name, "{form}ˤ%dʸʾϤƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MAX_INT) {
-			$this->ae->add($name, "{form}ˤ%dʲο()ϤƲ", $code, $value['max']);
+			$this->ae->add($name, "{form}ˤ%dʲο()ϤƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_MAX_FLOAT) {
-			$this->ae->add($name, "{form}ˤ%fʲο()ϤƲ", $code, $value['max']);
+			$this->ae->add($name, "{form}ˤ%fʲο()ϤƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_MAX_DATETIME) {
-			$this->ae->add($name, "{form}ˤ%sդϤƲ", $code, $value['max']);
+			$this->ae->add($name, "{form}ˤ%sդϤƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_MAX_FILE) {
-			$this->ae->add($name, "{form}ˤ%dKBʲΥեꤷƲ", $code, $value['max']);
+			$this->ae->add($name, "{form}ˤ%dKBʲΥեꤷƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_MAX_STRING) {
-			$this->ae->add($name, "{form}%dʸʲϤƲ", $code, $value['max']);
+			$this->ae->add($name, "{form}%dʸʲϤƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_REGEXP) {
 			$message = "{form}ϤƤ";
@@ -659,14 +674,14 @@ class Ethna_ActionForm
 		if ($type == VAR_TYPE_FILE) {
 			if ($def['required'] && ($var == null || $var['size'] == 0)) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_REQUIRED);
+					$this->handleError($name, E_FORM_REQUIRED);
 				}
 				return false;
 			}
 		} else {
 			if ($def['required'] && strlen($var) == 0) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_REQUIRED);
+					$this->handleError($name, E_FORM_REQUIRED);
 				}
 				return false;
 			}
@@ -677,28 +692,28 @@ class Ethna_ActionForm
 			if ($type == VAR_TYPE_INT) {
 				if (!preg_match('/^-?\d+$/', $var)) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_WRONGTYPE_INT);
+						$this->handleError($name, E_FORM_WRONGTYPE_INT);
 					}
 					return false;
 				}
 			} else if ($type == VAR_TYPE_FLOAT) {
 				if (!preg_match('/^-?\d+$/', $var) && !preg_match('/^-?\d+\.\d+$/', $var)) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_WRONGTYPE_FLOAT);
+						$this->handleError($name, E_FORM_WRONGTYPE_FLOAT);
 					}
 					return false;
 				}
 			} else if ($type == VAR_TYPE_DATETIME) {
 				if (strtotime($var) == -1) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_WRONGTYPE_DATETIME);
+						$this->handleError($name, E_FORM_WRONGTYPE_DATETIME);
 					}
 					return false;
 				}
 			} else if ($type == VAR_TYPE_BOOLEAN) {
 				if ($var != "1" && $var != "0") {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_WRONGTYPE_BOOLEAN);
+						$this->handleError($name, E_FORM_WRONGTYPE_BOOLEAN);
 					}
 					return false;
 				}
@@ -711,14 +726,14 @@ class Ethna_ActionForm
 		if ($type == VAR_TYPE_INT && $var !== "") {
 			if (!is_null($def['min']) && $var < $def['min']) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MIN_INT);
+					$this->handleError($name, E_FORM_MIN_INT);
 				}
 				return false;
 			}
 		} else if ($type == VAR_TYPE_FLOAT && $var !== "") {
 			if (!is_null($def['min']) && $var < $def['min']) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MIN_FLOAT);
+					$this->handleError($name, E_FORM_MIN_FLOAT);
 				}
 				return false;
 			}
@@ -728,7 +743,7 @@ class Ethna_ActionForm
 				$t_var = strtotime($var);
 				if ($t_var < $t_min) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_MIN_DATETIME);
+						$this->handleError($name, E_FORM_MIN_DATETIME);
 					}
 				}
 				return false;
@@ -738,7 +753,7 @@ class Ethna_ActionForm
 				$st = @stat($var['tmp_name']);
 				if ($st[7] < $def['min'] * 1024) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_MIN_FILE);
+						$this->handleError($name, E_FORM_MIN_FILE);
 					}
 					return false;
 				}
@@ -746,7 +761,7 @@ class Ethna_ActionForm
 		} else {
 			if (!is_null($def['min']) && strlen($var) < $def['min'] && $var !== "") {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MIN_STRING);
+					$this->handleError($name, E_FORM_MIN_STRING);
 				}
 				return false;
 			}
@@ -756,14 +771,14 @@ class Ethna_ActionForm
 		if ($type == VAR_TYPE_INT && $var !== "") {
 			if (!is_null($def['max']) && $var > $def['max']) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MAX_INT);
+					$this->handleError($name, E_FORM_MAX_INT);
 				}
 				return false;
 			}
 		} else if ($type == VAR_TYPE_FLOAT && $var !== "") {
 			if (!is_null($def['max']) && $var > $def['max']) {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MAX_FLOAT);
+					$this->handleError($name, E_FORM_MAX_FLOAT);
 				}
 				return false;
 			}
@@ -773,7 +788,7 @@ class Ethna_ActionForm
 				$t_var = strtotime($var);
 				if ($t_var > $t_min) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_MAX_DATETIME);
+						$this->handleError($name, E_FORM_MAX_DATETIME);
 					}
 				}
 				return false;
@@ -783,7 +798,7 @@ class Ethna_ActionForm
 				$st = @stat($var['tmp_name']);
 				if ($st[7] > $def['max'] * 1024) {
 					if ($test == false) {
-						$this->_handleError($name, $def, E_FORM_MAX_FILE);
+						$this->handleError($name, E_FORM_MAX_FILE);
 					}
 					return false;
 				}
@@ -791,23 +806,27 @@ class Ethna_ActionForm
 		} else {
 			if (!is_null($def['max']) && strlen($var) > $def['max'] && $var !== "") {
 				if ($test == false) {
-					$this->_handleError($name, $def, E_FORM_MAX_STRING);
+					$this->handleError($name, E_FORM_MAX_STRING);
 				}
 				return false;
 			}
 		}
 
 		// regexp
-		if ($def['regexp'] != null && strlen($var) > 0 && preg_match($def['regexp'], $var) == 0) {
+		if ($type != VAR_TYPE_FILE && $def['regexp'] != null && strlen($var) > 0 && preg_match($def['regexp'], $var) == 0) {
 			if ($test == false) {
-				$this->_handleError($name, $def, E_FORM_REGEXP);
+				$this->handleError($name, E_FORM_REGEXP);
 			}
 			return false;
 		}
 
 		// custom (TODO: respect $test flag)
 		if ($def['custom'] != null) {
-			$this->{$def['custom']}($name);
+			if (isset($this->form[$name]['type']) && is_array($this->form[$name]['type']) == false) {
+				$this->{$def['custom']}($name);
+			} else {
+				// ξǰǥ᥽åɤ¹Ԥ뤿᥹å
+			}
 		}
 
 		return true;
