@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_AppObject.php,v 1.5 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_AppObject.php,v 1.7 2005/01/12 17:10:31 fujimoto Exp $
  */
 
 // {{{ Ethna_AppObject
@@ -24,65 +24,41 @@ class Ethna_AppObject
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Backend		backend֥
-	 */
+	/**	@var	object	Ethna_Backend		backend֥ */
 	var $backend;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥ */
 	var $config;
 
-	/**
-	 *  @var    object  Ethna_DB      DB֥
-	 */
+	/**  @var    object  Ethna_DB      DB֥ */
 	var $db;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥(ά) */
 	var $af;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
-	/**
-	 *	@var	array	ơ֥
-	 */
+	/**	@var	array	ơ֥ */
 	var	$table_def = array();
 
-	/**
-	 *	@var	array	ץѥƥ
-	 */
+	/**	@var	array	ץѥƥ */
 	var	$prop_def = array();
 
-	/**
-	 *	@var	array	ץѥƥ
-	 */
+	/**	@var	array	ץѥƥ */
 	var	$prop = null;
 	var $prop_backup = null;
 
-	/** 
-	 *	@var	array	ץ饤ޥꥭ
-	 */
+	/** @var	array	ץ饤ޥꥭ */
 	var	$id_def = null;
 
-	/**
-	 *	@var	int		֥ID
-	 */
+	/**	@var	int		֥ID */
 	var	$id = null;
 
 	/**#@-*/
@@ -1135,9 +1111,7 @@ class Ethna_AppObject
 
 			if (is_object($v)) {
 				// Ethna_AppSearchObjectꤵƤ
-				$tmp = $v->value;
-				Ethna_AppSQL::escapeSQL($tmp);
-				$condition .= Ethna_AppSQL::getCondition("$t.$k", $tmp, $v->condition);
+				$condition .= $v->toString("$t.$k");
 			} else if (is_array($v) && count($v) > 0 && is_object($v[0])) {
 				// Ethna_AppSearchObjectǻꤵƤ
 				$n = 0;
@@ -1145,9 +1119,7 @@ class Ethna_AppObject
 					if ($n > 0) {
 						$condition .= " AND ";
 					}
-					$tmp = $so->value;
-					Ethna_AppSQL::escapeSQL($tmp);
-					$condition .= Ethna_AppSQL::getCondition("$t.$k", $tmp, $so->condition);
+					$condition .= $so->toStrong("$t.$k");
 					$n++;
 				}
 			} else if ($prop_def[$k]['type'] == VAR_TYPE_STRING) {
