@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Backend.php,v 1.6 2004/12/23 06:03:12 fujimoto Exp $
+ *	@version	$Id: Ethna_Backend.php,v 1.9 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_Backend
@@ -23,64 +23,40 @@ class Ethna_Backend
 	 *	@access		private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Controller	controller֥
-	 */
+	/**	@var	object	Ethna_Controller	controller֥ */
 	var	$controller;
 
-	/**
-	 *	@var	object	Ethna_Controller	controller֥($controllerξά)
-	 */
+	/**	@var	object	Ethna_Controller	controller֥($controllerξά) */
 	var	$ctl;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥ */
 	var	$config;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥ */
 	var $action_error;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥($action_errorξά)
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥($action_errorξά) */
 	var $ae;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥($action_formξά)
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥($action_formξά) */
 	var $af;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
-	/**
-	 *	@var	array	Ethna_DB֥ȤǼ
-	 */
+	/**	@var	array	Ethna_DB֥ȤǼ */
 	var $db;
 
-	/**
-	 *	@var	object	Ethna_Logger		֥
-	 */
+	/**	@var	object	Ethna_Logger		֥ */
 	var $logger;
 
-	/**
-	 *	@var	array	ޥ͡㥪֥ȥå
-	 */
+	/**	@var	array	ޥ͡㥪֥ȥå */
 	var $manager = array();
 
 	/**#@-*/
@@ -328,8 +304,17 @@ class Ethna_Backend
 		$action_class =& new $action_class_name($this);
 
 		// μ¹
+		$forward_name = $action_class->authenticate();
+		if ($forward_name === false) {
+			return null;
+		} else if ($forward_name !== null) {
+			return $forward_name;
+		}
+
 		$forward_name = $action_class->prepare();
-		if ($forward_name != null) {
+		if ($forward_name === false) {
+			return null;
+		} else if ($forward_name !== null) {
 			return $forward_name;
 		}
 
@@ -362,8 +347,9 @@ class Ethna_Backend
 		}
 		$dsn_persistent = $this->controller->getDSN_persistent($type);
 
-		$db_class = $this->controller->getClass('db');
-		$this->db[$key] =& new $db_class($this->controller, $dsn, $dsn_persistent);
+		$class_factory =& $this->controller->getClassFactory();
+		$db_class_name = $class_factory->getObjectName('db');
+		$this->db[$key] =& new $db_class_name($this->controller, $dsn, $dsn_persistent);
 		$r = $this->db[$key]->connect();
 		if (Ethna::isError($r)) {
 			$this->db[$key] = null;
