@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_DB.php,v 1.4 2004/12/10 10:02:50 fujimoto Exp $
+ *	@version	$Id: Ethna_DB.php,v 1.5 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_DB
@@ -23,39 +23,25 @@ class Ethna_DB
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	DB				PEAR DB֥
-	 */
+	/**	@var	object	DB				PEAR DB֥ */
 	var $db;
 
-	/**
-	 *	@var	object	Ethna_Logger	֥
-	 */
+	/**	@var	object	Ethna_Logger	֥ */
 	var $logger;
 
-	/**
-	 *	@var	object	Ethna_AppSQL	SQL֥
-	 */
+	/**	@var	object	Ethna_AppSQL	SQL֥ */
 	var $sql;
 
-	/**
-	 *	@var	string	DB(mysql, pgsql...)
-	 */
+	/**	@var	string	DB(mysql, pgsql...) */
 	var $type;
 
-	/**
-	 *	@var	string	DSN
-	 */
+	/**	@var	string	DSN */
 	var $dsn;
 
-	/**
-	 *	@var	bool	³³ե饰
-	 */
+	/**	@var	bool	³³ե饰 */
 	var $persistent;
 
-	/**
-	 *	@var	array	ȥ󥶥å
-	 */
+	/**	@var	array	ȥ󥶥å */
 	var	$transaction = array();
 
 	/**#@-*/
