@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_InfoManager.php,v 1.2 2004/12/23 06:03:12 fujimoto Exp $
+ *	@version	$Id: Ethna_InfoManager.php,v 1.4 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_InfoManager
@@ -23,33 +23,26 @@ class Ethna_InfoManager extends Ethna_AppManager
 	 *	@access	private
 	 */
 	
-	/**
-	 *	@var	object	Ethna_Controller	ȥ饪֥
-	 */
+	/**	@var	object	Ethna_Controller	ȥ饪֥ */
 	var	$ctl;
 
-	/**
-	 *	@var	array	󥹥ץȲϷ̥åե
-	 */
+	/**	@var	object	Ethna_ClassFactory	饹եȥꥪ֥ */
+	var	$class_factory;
+
+	/**	@var	array	󥹥ץȲϷ̥åե */
 	var	$cache_class_list_file;
 
-	/**
-	 *	@var	array	󥹥ץȲϷ̥å
-	 */
+	/**	@var	array	󥹥ץȲϷ̥å */
 	var	$cache_class_list;
 
-	/**
-	 *	@var	array	[°]DBװ
-	 */
+	/**	@var	array	[°]DBװ */
 	var	$db_type_list = array(
 		DB_TYPE_RW		=> array('name' => 'DB_TYPE_RW'),
 		DB_TYPE_RO		=> array('name' => 'DB_TYPE_RO'),
 		DB_TYPE_MISC	=> array('name' => 'DB_TYPE_MISC'),
 	);
 
-	/**
-	 *	@var	array	[°]ե෿
-	 */
+	/**	@var	array	[°]ե෿ */
 	var	$form_type_list = array(
 		FORM_TYPE_TEXT		=> array('name' => 'ƥȥܥå'),
 		FORM_TYPE_PASSWORD	=> array('name' => 'ѥ'),
@@ -61,9 +54,7 @@ class Ethna_InfoManager extends Ethna_AppManager
 		FORM_TYPE_FILE		=> array('name' => 'ե'),
 	);
 
-	/**
-	 *	@var	array	[°]ѿ
-	 */
+	/**	@var	array	[°]ѿ */
 	var	$var_type_list = array(
 		VAR_TYPE_INT		=> array('name' => ''),
 		VAR_TYPE_FLOAT		=> array('name' => 'ư'),
@@ -207,7 +198,7 @@ class Ethna_InfoManager extends Ethna_AppManager
 		closedir($dh);
 
 		foreach ($child_dir_list as $child_dir) {
-			$tmp = $this->_analyzeActionList($child_dir);
+			$tmp = $this->_analyzeActionList($child_dir . "/");
 			$r = array_merge($r, $tmp);
 		}
 
@@ -620,10 +611,10 @@ class Ethna_InfoManager extends Ethna_AppManager
 
 		// class
 		$elts = array();
-		$elts[''] = $this->ctl->getClass('config');
-		$elts['DB'] = $this->ctl->getClass('db');
-		$elts[''] = $this->ctl->getClass('logger');
-		$elts['SQL'] = $this->ctl->getClass('sql');
+		$elts[''] = $this->class_factory->getObjectName('config');
+		$elts['DB'] = $this->class_factory->getObjectName('db');
+		$elts[''] = $this->class_factory->getObjectName('logger');
+		$elts['SQL'] = $this->class_factory->getObjectName('sql');
 		$r['饹'] = $elts;
 
 		// DB
