@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_ViewClass.php,v 1.3 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_ViewClass.php,v 1.4 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_ViewClass
@@ -23,54 +23,34 @@ class Ethna_ViewClass
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Backend		backend֥
-	 */
+	/**	@var	object	Ethna_Backend		backend֥ */
 	var $backend;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥	
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥	*/
 	var $config;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥ */
 	var $action_error;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥(ά) */
 	var $ae;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥(ά) */
 	var $af;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
-	/**
-	 *	@var	string	̾
-	 */
+	/**	@var	string	̾ */
 	var $forward_name;
 
-	/**
-	 *	@var	string	ƥץ졼ȥե̾
-	 */
+	/**	@var	string	ƥץ졼ȥե̾ */
 	var $forward_path;
 
 	/**#@-*/
