@@ -4,7 +4,7 @@
  *
  *	@author		your name
  *	@package	{$project_id}
- *	@version	$Id: skel.action.php,v 1.3 2004/12/14 07:23:12 fujimoto Exp $
+ *	@version	$Id: skel.action.php,v 1.4 2005/01/04 12:53:26 fujimoto Exp $
  */
 
 /**
@@ -50,7 +50,7 @@ class {$action_class} extends Ethna_ActionClass
 	 *	{$action_name}
 	 *
 	 *	@access	public
-	 *	@return	string		Forward(ｪλʤnull)
+	 *	@return	string		̾(ｪλʤnull, λʤfalse)
 	 */
 	function prepare()
 	{
